@@ -1,9 +1,10 @@
 from ._pydantic_core import (
     PydanticCustomError,
-    PydanticKindError,
+    PydanticKnownError,
     PydanticOmit,
     SchemaError,
     SchemaValidator,
+    Url,
     ValidationError,
     __version__,
 )
@@ -14,9 +15,10 @@ __all__ = (
     'CoreConfig',
     'CoreSchema',
     'SchemaValidator',
+    'Url',
     'SchemaError',
     'ValidationError',
     'PydanticCustomError',
-    'PydanticKindError',
+    'PydanticKnownError',
     'PydanticOmit',
 )
