@@ -14,11 +14,13 @@ mod input;
 mod lookup_key;
 mod questions;
 mod recursion_guard;
+mod url;
 mod validators;
 
 // required for benchmarks
+pub use self::url::PyUrl;
 pub use build_tools::SchemaError;
-pub use errors::{list_all_errors, PydanticCustomError, PydanticKindError, PydanticOmit, ValidationError};
+pub use errors::{list_all_errors, PydanticCustomError, PydanticKnownError, PydanticOmit, ValidationError};
 pub use validators::SchemaValidator;
 
 pub fn get_version() -> String {
@@ -39,8 +41,9 @@ fn _pydantic_core(_py: Python, m: &PyModule) -> PyResult<()> {
     m.add_class::<ValidationError>()?;
     m.add_class::<SchemaError>()?;
     m.add_class::<PydanticCustomError>()?;
-    m.add_class::<PydanticKindError>()?;
+    m.add_class::<PydanticKnownError>()?;
     m.add_class::<PydanticOmit>()?;
+    m.add_class::<self::url::PyUrl>()?;
     m.add_function(wrap_pyfunction!(list_all_errors, m)?)?;
     Ok(())
 }
