@@ -1,7 +1,7 @@
 use pyo3::prelude::*;
 use pyo3::types::PyDict;
 
-use crate::errors::{ErrorKind, ValError, ValResult};
+use crate::errors::{ErrorType, ValError, ValResult};
 use crate::input::Input;
 use crate::recursion_guard::RecursionGuard;
 
@@ -33,7 +33,7 @@ impl Validator for CallableValidator {
     ) -> ValResult<'data, PyObject> {
         match input.callable() {
             true => Ok(input.to_object(py)),
-            false => Err(ValError::new(ErrorKind::CallableType, input)),
+            false => Err(ValError::new(ErrorType::CallableType, input)),
         }
     }
 
