@@ -3,7 +3,7 @@ use pyo3::prelude::*;
 use pyo3::types::{PyDict, PyList, PyTuple};
 
 use crate::build_tools::{is_strict, SchemaDict};
-use crate::errors::{ErrorKind, ValError, ValLineError, ValResult};
+use crate::errors::{ErrorType, ValError, ValLineError, ValResult};
 use crate::input::{GenericCollection, Input};
 use crate::recursion_guard::RecursionGuard;
 
@@ -47,7 +47,7 @@ impl TupleVariableValidator {
         let py = schema.py();
         let item_validator = get_items_schema(schema, config, build_context)?;
         let inner_name = item_validator.as_ref().map(|v| v.get_name()).unwrap_or("any");
-        let name = format!("tuple[{}, ...]", inner_name);
+        let name = format!("tuple[{inner_name}, ...]");
         Ok(Self {
             strict: crate::build_tools::is_strict(schema, config)?,
             item_validator,
@@ -135,7 +135,7 @@ impl TuplePositionalValidator {
                 Some(v) => Some(Box::new(build_validator(v, config, build_context)?)),
                 None => None,
             },
-            name: format!("tuple[{}]", descr),
+            name: format!("tuple[{descr}]"),
         }
         .into())
     }
@@ -174,7 +174,7 @@ impl Validator for TuplePositionalValidator {
                             if let Some(value) = get_default(py, &validator)? {
                                 output.push(value.as_ref().clone_ref(py));
                             } else {
-                                errors.push(ValLineError::new_with_loc(ErrorKind::Missing, input, index));
+                                errors.push(ValLineError::new_with_loc(ErrorType::Missing, input, index));
                             }
                         }
                     }
@@ -197,7 +197,7 @@ impl Validator for TuplePositionalValidator {
                         }
                         None => {
                             errors.push(ValLineError::new(
-                                ErrorKind::TooLong {
+                                ErrorType::TooLong {
                                     field_type: "Tuple".to_string(),
                                     max_length: expected_length,
                                     actual_length: collection.generic_len()?,
