@@ -3,7 +3,7 @@ from datetime import datetime, timezone
 from typing import Optional
 
 import pytest
-from dirty_equals import AnyThing, IsBytes, IsList, IsStr
+from dirty_equals import AnyThing, IsBytes, IsStr, IsTuple
 from hypothesis import given, strategies
 from typing_extensions import TypedDict
 
@@ -43,11 +43,11 @@ def test_datetime_binary(datetime_schema, data):
     except ValidationError as exc:
         assert exc.errors() == [
             {
-                'kind': 'datetime_parsing',
-                'loc': [],
-                'message': IsStr(regex='Input should be a valid datetime, .+'),
-                'input_value': IsBytes(),
-                'context': {'error': IsStr()},
+                'type': 'datetime_parsing',
+                'loc': (),
+                'msg': IsStr(regex='Input should be a valid datetime, .+'),
+                'input': IsBytes(),
+                'ctx': {'error': IsStr()},
             }
         ]
 
@@ -107,10 +107,10 @@ def test_recursive_cycles(recursive_schema, data):
     except ValidationError as exc:
         assert exc.errors() == [
             {
-                'kind': 'recursion_loop',
-                'loc': IsList(length=(1, None)),
-                'message': 'Recursion error - cyclic reference detected',
-                'input_value': AnyThing(),
+                'type': 'recursion_loop',
+                'loc': IsTuple(length=(1, None)),
+                'msg': 'Recursion error - cyclic reference detected',
+                'input': AnyThing(),
             }
         ]
 
@@ -131,3 +131,19 @@ def test_pytimedelta_as_timedelta(dt):
     total_seconds = (1 if pos == 'true' else -1) * (int(day) * 86_400 + int(sec) + int(micro) / 1_000_000)
 
     assert total_seconds == pytest.approx(dt.total_seconds())
+
+
+@pytest.fixture(scope='module')
+def url_validator():
+    return SchemaValidator({'type': 'url'})
+
+
+@given(strategies.text())
+def test_urls_text(url_validator, text):
+    try:
+        url_validator.validate_python(text)
+    except ValidationError as exc:
+        assert exc.error_count() == 1
+        error = exc.errors()[0]
+        assert error['type'] == 'url_error'
+        assert error['ctx']['error'] == 'relative URL without a base'
