@@ -16,7 +16,7 @@ from ..conftest import Err, PyAndJson
         pytest.param(date(2022, 6, 8), date(2022, 6, 8), id='date'),
         pytest.param('2022-06-08', date(2022, 6, 8), id='str'),
         pytest.param(b'2022-06-08', date(2022, 6, 8), id='bytes'),
-        pytest.param((1,), Err('Input should be a valid date [kind=date_type'), id='tuple'),
+        pytest.param((1,), Err('Input should be a valid date [type=date_type'), id='tuple'),
         pytest.param(1654646400, date(2022, 6, 8), id='int'),
         pytest.param(1654646400.00, date(2022, 6, 8), id='float'),
         pytest.param(Decimal('1654646400'), date(2022, 6, 8), id='decimal'),
@@ -29,22 +29,22 @@ from ..conftest import Err, PyAndJson
             datetime(2022, 6, 8, 12),
             Err(
                 'Datetimes provided to dates should have zero time '
-                '- e.g. be exact dates [kind=date_from_datetime_inexact'
+                '- e.g. be exact dates [type=date_from_datetime_inexact'
             ),
             id='datetime-inexact',
         ),
         pytest.param(True, Err('Input should be a valid date'), id='bool'),
-        pytest.param(time(1, 2, 3), Err('Input should be a valid date [kind=date_type'), id='time'),
+        pytest.param(time(1, 2, 3), Err('Input should be a valid date [type=date_type'), id='time'),
         pytest.param(
             float('nan'),
-            Err('Input should be a valid date or datetime, NaN values not permitted [kind=date_from_datetime_parsing,'),
+            Err('Input should be a valid date or datetime, NaN values not permitted [type=date_from_datetime_parsing,'),
             id='nan',
         ),
         pytest.param(
             float('inf'),
             Err(
                 'Input should be a valid date or datetime, dates after 9999 are not supported as unix timestamps '
-                '[kind=date_from_datetime_parsing,'
+                '[type=date_from_datetime_parsing,'
             ),
             id='inf',
         ),
@@ -52,7 +52,7 @@ from ..conftest import Err, PyAndJson
             float('-inf'),
             Err(
                 'Input should be a valid date or datetime, dates before 1600 are not supported as unix timestamps '
-                '[kind=date_from_datetime_parsing,'
+                '[type=date_from_datetime_parsing,'
             ),
             id='-inf',
         ),
@@ -82,19 +82,19 @@ def test_date(input_value, expected):
             1654646401,
             Err(
                 'Datetimes provided to dates should have zero time '
-                '- e.g. be exact dates [kind=date_from_datetime_inexact'
+                '- e.g. be exact dates [type=date_from_datetime_inexact'
             ),
         ),
-        ('wrong', Err('Input should be a valid date or datetime, input is too short [kind=date_from_datetime_parsing')),
+        ('wrong', Err('Input should be a valid date or datetime, input is too short [type=date_from_datetime_parsing')),
         ('2000-02-29', date(2000, 2, 29)),
         (
             '2001-02-29',
             Err(
                 'Input should be a valid date or datetime, '
-                'day value is outside expected range [kind=date_from_datetime_parsing'
+                'day value is outside expected range [type=date_from_datetime_parsing'
             ),
         ),
-        ([1], Err('Input should be a valid date [kind=date_type')),
+        ([1], Err('Input should be a valid date [type=date_type')),
     ],
 )
 def test_date_json(py_and_json: PyAndJson, input_value, expected):
@@ -113,11 +113,11 @@ def test_date_json(py_and_json: PyAndJson, input_value, expected):
     'input_value,expected',
     [
         (date(2022, 6, 8), date(2022, 6, 8)),
-        ('2022-06-08', Err('Input should be a valid date [kind=date_type')),
-        (b'2022-06-08', Err('Input should be a valid date [kind=date_type')),
-        (1654646400, Err('Input should be a valid date [kind=date_type')),
-        (True, Err('Input should be a valid date [kind=date_type')),
-        (datetime(2022, 6, 8), Err('Input should be a valid date [kind=date_type')),
+        ('2022-06-08', Err('Input should be a valid date [type=date_type')),
+        (b'2022-06-08', Err('Input should be a valid date [type=date_type')),
+        (1654646400, Err('Input should be a valid date [type=date_type')),
+        (True, Err('Input should be a valid date [type=date_type')),
+        (datetime(2022, 6, 8), Err('Input should be a valid date [type=date_type')),
     ],
     ids=repr,
 )
@@ -137,9 +137,9 @@ def test_date_strict(input_value, expected):
         ('"2022-06-08"', date(2022, 6, 8)),
         (
             '"foobar"',
-            Err('Input should be a valid date in the format YYYY-MM-DD, input is too short [kind=date_parsing,'),
+            Err('Input should be a valid date in the format YYYY-MM-DD, input is too short [type=date_parsing,'),
         ),
-        ('1654646400', Err('Input should be a valid date [kind=date_type')),
+        ('1654646400', Err('Input should be a valid date [type=date_type')),
     ],
 )
 def test_date_strict_json(input_value, expected):
@@ -158,11 +158,11 @@ def test_date_strict_json_ctx():
         v.validate_json('"foobar"')
     assert exc_info.value.errors() == [
         {
-            'kind': 'date_parsing',
-            'loc': [],
-            'message': 'Input should be a valid date in the format YYYY-MM-DD, input is too short',
-            'input_value': 'foobar',
-            'context': {'error': 'input is too short'},
+            'type': 'date_parsing',
+            'loc': (),
+            'msg': 'Input should be a valid date in the format YYYY-MM-DD, input is too short',
+            'input': 'foobar',
+            'ctx': {'error': 'input is too short'},
         }
     ]
 
@@ -175,18 +175,18 @@ def test_date_strict_json_ctx():
         (
             {'le': date(2000, 1, 1)},
             '2000-01-02',
-            Err('Input should be less than or equal to 2000-01-01 [kind=less_than_equal,'),
+            Err('Input should be less than or equal to 2000-01-01 [type=less_than_equal,'),
         ),
         ({'lt': '2000-01-01'}, '1999-12-31', date(1999, 12, 31)),
-        ({'lt': '2000-01-01'}, '2000-01-01', Err('Input should be less than 2000-01-01 [kind=less_than,')),
+        ({'lt': '2000-01-01'}, '2000-01-01', Err('Input should be less than 2000-01-01 [type=less_than,')),
         ({'ge': '2000-01-01'}, '2000-01-01', date(2000, 1, 1)),
         (
             {'ge': date(2000, 1, 1)},
             '1999-12-31',
-            Err('Input should be greater than or equal to 2000-01-01 [kind=greater_than_equal,'),
+            Err('Input should be greater than or equal to 2000-01-01 [type=greater_than_equal,'),
         ),
         ({'gt': date(2000, 1, 1)}, '2000-01-02', date(2000, 1, 2)),
-        ({'gt': date(2000, 1, 1)}, '2000-01-01', Err('Input should be greater than 2000-01-01 [kind=greater_than,')),
+        ({'gt': date(2000, 1, 1)}, '2000-01-01', Err('Input should be greater than 2000-01-01 [type=greater_than,')),
     ],
 )
 def test_date_kwargs(kwargs: Dict[str, Any], input_value, expected):
@@ -229,8 +229,8 @@ def test_union():
     [
         ('2022-06-08', date(2022, 6, 8)),
         (1654646400, date(2022, 6, 8)),
-        ('2068-06-08', Err('Date should be in the past [kind=date_past,')),
-        (3105734400, Err('Date should be in the past [kind=date_past,')),
+        ('2068-06-08', Err('Date should be in the past [type=date_past,')),
+        (3105734400, Err('Date should be in the past [type=date_past,')),
     ],
 )
 def test_date_past(py_and_json: PyAndJson, input_value, expected):
@@ -249,8 +249,8 @@ def test_date_past(py_and_json: PyAndJson, input_value, expected):
 @pytest.mark.parametrize(
     'input_value,expected',
     [
-        ('2022-06-08', Err('Date should be in the future [kind=date_future,')),
-        (1654646400, Err('Date should be in the future [kind=date_future,')),
+        ('2022-06-08', Err('Date should be in the future [type=date_future,')),
+        (1654646400, Err('Date should be in the future [type=date_future,')),
         ('2068-06-08', date(2068, 6, 8)),
         (3105734400, date(2068, 6, 1)),
     ],
@@ -281,5 +281,5 @@ def test_date_past_future_today():
 
 
 def test_offset_too_large():
-    with pytest.raises(SchemaError, match=r'Input should be less than 86400 \[kind=less_than,'):
+    with pytest.raises(SchemaError, match=r'Input should be less than 86400 \[type=less_than,'):
         SchemaValidator(core_schema.date_schema(now_op='past', now_utc_offset=24 * 3600))
